@@ -60,6 +60,7 @@ class BaseAccessController(object):
         self.memosAge = {}
 
     def isAuthorised(self, person=None, actionName=None, protectedObject=None, *args, **kwds):
+        # Todo: Decide whether to move this log message into 'isAccessAuth
         if moddebug:
             msg = "AccessController: Deciding access for %s to %s %s." % (
                 self.summarizePerson(person), actionName.lower(),
@@ -118,7 +119,8 @@ class BaseAccessController(object):
         isAuthorised = self.memosCache.get(memoName, None)
         isExpired = False
         if memoName in self.memosAge:
-            isExpired = int(dm.time.getLocalNow() - self.memosAge[memoName]) >= self.memosExpire
+            ageDelta = dm.times.getLocalNow() - self.memosAge[memoName]
+            isExpired = ageDelta.days >= 0 or ageDelta.seconds >= self.memosExpire
         if isExpired:
             if memoName in self.memosFifo:
                 self.memosFifo.remove(memoName)
@@ -243,7 +245,7 @@ class BaseAccessController(object):
         return self.visitor
 
     def summarizePerson(self, person):
-        return person and person.name or 'None'
+        return person and person.name or self.dictionary[VISITOR_NAME]
 
     def summarizeProtectedObject(self, protectedObject):
         if type(protectedObject) == type:
