@@ -203,17 +203,23 @@ class InitialiseFilesystem(object):
             raise Exception, "installPath is missing."
         installPath = os.path.normpath(installPath)
         try:
-            fullResourcePath = pkg_resources.resource_filename(
-                pkg_resources.Requirement.parse(self.systemName),
-                '%s/%s' % (self.packageName, resourcePath )
-            )
-        except Exception, inst:
-            msg = "Couldn't make full '%s' package resource path for '%s': %s" % (
-                self.packageName,
-                resourcePath,
-                repr(inst)
-            )
-            raise Exception, msg
+            packageModule = __import__(self.packageName, '', '', '*')
+            packagePath = os.path.dirname(packageModule.__file__)
+            fullResourcePath = os.path.join(packagePath, resourcePath)
+        except:
+            # Hopefully this isn't necessary anymore. :-)
+            try:
+                fullResourcePath = pkg_resources.resource_filename(
+                    pkg_resources.Requirement.parse(self.systemName),
+                    '%s/%s' % (self.packageName, resourcePath )
+                )
+            except Exception, inst:
+                msg = "Couldn't make full '%s' package resource path for '%s': %s" % (
+                    self.packageName,
+                    resourcePath,
+                    repr(inst)
+                )
+                raise Exception, msg
         if os.path.exists(installPath):
             print "Skipping %s: The folder already exists: %s" % (purpose, installPath)
         else:
