@@ -1,6 +1,6 @@
 # todo: delete?
 
-from dm.command import Command
+from dm.command.base import Command
 
 class RoleCommand(Command):
     "Abstract Role command."
