@@ -120,7 +120,9 @@ class TestPerson(TestCase):
         self.failUnless(self.person, "Old record could not be re-created.")
 
     def test_update(self):
-        self.assertEquals(self.person.fullname, "", "Record already has a 'fullname'.")
+        # Trouble with sqlite and Python 2.7: writing strings of '' causes record to return with value of None rather than ''.
+        #self.assertEquals(self.person.fullname, "", "Record already has a 'fullname': %s" % repr(self.person.fullname))
+        self.assertFalse(self.person.fullname, "Record already has a 'fullname': %s" % repr(self.person.fullname))
         self.person.fullname = "Test Person"
         self.assertEquals(self.person.fullname, "Test Person", "Record 'fullname' attribute incorrect.")
         person = self.database.findRecord('Person', name='TestPerson')
