@@ -20,7 +20,7 @@ class SystemDictionary(dict):
         self.environment = SystemEnvironment(self.getSystemName())
         self.assertSystemEnvironment()
         self.setDefaultWords()
-        self.makeConfigFilePath()
+        self.initConfigFilePath()
         self.assertConfigFileExists()
         self.makeConfigFileReader()
         self.initConfigFileReader()
@@ -53,6 +53,9 @@ class SystemDictionary(dict):
         self[SYSTEM_SERVICE_NAME] = self.getSystemServiceName()
         self[SYSTEM_MODE]         = 'production'
         self[SYSTEM_VERSION]      = self.getSystemVersion()
+        self[SYSTEM_USER_NAME]    = self.getSystemUserName()
+        self[FILESYSTEM_PATH]     = ''
+        self[PASSWORD_DIGEST_SECRET] = 'not-a-secret'
         self[VISITOR_NAME]        = 'visitor'
         self[VISITOR_ROLE]        = 'Visitor'
         self[INITIAL_PERSON_ROLE] = 'Visitor'
@@ -61,13 +64,16 @@ class SystemDictionary(dict):
         self[AUTH_COOKIE_NAME]    = '%s_auth' % self[SYSTEM_NAME]
         self[NO_AUTH_COOKIE_NAME] = '%s_no_auth' % self[SYSTEM_NAME]
         self[LOG_PATH]            = ''
-        self[LOG_LEVEL]           = 'ERROR'
+        self[LOG_LEVEL]           = 'WARNING'
+        self[APACHE_PYTHON_MODULE]= 'mod_wsgi'
         self[APACHE_IP_ADDRESS]   = '*'
         self[APACHE_CONFIG_PATH]  = ''
-        self[APACHE_RELOAD_CMD]   = '' #'sudo /etc/init.d/apache2 reload'
+        self[APACHE_RELOAD_CMD]   = 'sudo /etc/init.d/apache2 graceful'
+        self[APACHE_WSGI_REDIRECT_DELAY] = '12'
         self[SKIP_APACHE_RELOAD]  = ''
         self[APACHE_CONFIGTEST_CMD] = '' #'sudo /etc/init.d/apache2 configtest'
         self[WSGI_SCRIPT_PATH]    = ''
+        self[WSGI_PROCESS_GROUP]  = self[SYSTEM_NAME]
         self[DOMAIN_NAME]         = self.getDomainName()
         self[HTTP_PORT]           = '80'
         self[HTTPS_PORT]          = '443'
@@ -82,14 +88,14 @@ class SystemDictionary(dict):
         self[TIMEZONE]            = '' # Defaults to unchanged environment.
         self[SERVICE_EMAIL]       = ''
         self[SMTP_HOST]           = ''
-        self[SKIP_EMAIL_SENDING]  = ''
+        self[ENABLE_EMAIL_SENDING]  = ''
         self[EMAIL_NOTIFY_CHANGES]= ''
         self[IMAGES_DIR_PATH]     = ''
         # Potential values: 'mysql', 'postgres', 'sqlite', 'firebird', 'sybase', 'maxdb', 'mssql'.
-        self[DB_TYPE]             = 'postgres' 
+        self[DB_TYPE]             = 'sqlite' 
         self[DB_HOST]             = 'localhost'
-        self[DB_NAME]             = self[SYSTEM_NAME]
-        self[DB_USER]             = self[DB_NAME]
+        self[DB_NAME]             = ''
+        self[DB_USER]             = ''
         self[DB_PASS]             = ''
         self[DB_SUPER_USER]       = ''
         self[DB_SUPER_PASS]       = ''
@@ -106,14 +112,13 @@ class SystemDictionary(dict):
         self[MEMOS_ENABLED]       = ''
         self[TEMPLATES_RESOURCE_PATH] = 'django/templates'
         self[MEDIA_RESOURCE_PATH] = 'django/media'
+        self[HTTP_AUTH_REALM] = ''
 
-    def makeConfigFilePath(self):
+    def initConfigFilePath(self):
         self.configFilePath = self.environment.getConfigFilePath().strip()
-        if not self.configFilePath:
-            raise MissingConfigurationPath("No configuration file path has been provided (export %s=/path/to/kforge.conf in the operating environment)." % self.environment.getConfigFilePathEnvironmentVariableName())
 
     def setConfigFilePathWord(self):
-        self[SYSTEM_CONFIG_PATH] = self.configFilePath
+        self[SYSTEM_CONFIG_PATH] = os.path.abspath(self.configFilePath)
 
     def assertConfigFileExists(self):
         if not os.path.isfile(self.configFilePath):
@@ -137,23 +142,55 @@ class SystemDictionary(dict):
     def setWordsFromConfigFile(self):
         configWords = self.configFileReader.keys()
         for configWord in configWords:
-            configValue = self.configFileReader[configWord]
+            configValue = self.configFileReader[configWord].strip()
             # Todo: Interestingly, converting all dict values to 
             # unicode breaks things quite a lot. Find out why!
             #if type(configValue) == str:
                 #configValue = configValue.decode('utf-8')
                 #print "%s %s" % (configWord, repr(configValue))
             self[configWord] = configValue
-        if self[LOG_PATH] == '':
-            raise Exception("No path for logging has been provided. Try setting '%s' in the configuration file: %s" % (LOG_PATH, self.configFilePath))
 
     def setWordsFromWords(self):
+        # Filesystem paths.
+        if not self[FILESYSTEM_PATH]:
+            configDirPath = os.path.dirname(self.configFilePath)
+            if os.path.basename(configDirPath) in ['etc', 'config']:
+                self[FILESYSTEM_PATH] = os.path.dirname(configDirPath)
+            else:
+                self[FILESYSTEM_PATH] = configDirPath
+
+        if not self[LOG_PATH]:
+            logFilePath = os.path.join('var', 'log', '%s.log' % self[SYSTEM_NAME])
+            self[LOG_PATH] = os.path.join(self[FILESYSTEM_PATH], logFilePath)
+
+        if not self[MEDIA_PATH]:
+            self[MEDIA_PATH] = os.path.join(self[FILESYSTEM_PATH], 'media')
+
+        if not self[DJANGO_TEMPLATES_DIR]:
+            self[DJANGO_TEMPLATES_DIR] = os.path.join(self[FILESYSTEM_PATH], 'templates')
+
+        if not self[APACHE_CONFIG_PATH]:
+            apacheConfigFilePath = os.path.join('var', 'httpd-autogenerated.conf')
+            self[APACHE_CONFIG_PATH] = os.path.join(self[FILESYSTEM_PATH], apacheConfigFilePath)
+
+        if not self[WSGI_SCRIPT_PATH]:
+            wsgiScriptPath = os.path.join('wsgi', '%s.wsgi' % self[SYSTEM_NAME])
+            self[WSGI_SCRIPT_PATH] = os.path.join(self[FILESYSTEM_PATH], wsgiScriptPath)
+
         # Media host and post.
         #if not self[MEDIA_HOST]:
         #    self[MEDIA_HOST] = self[DOMAIN_NAME]
         if not self[MEDIA_PORT]:
             self[MEDIA_PORT] = self[HTTP_PORT]
-        # Database super user.
+        # Database configuration.
+        if not self[DB_NAME]:
+            if self[DB_TYPE] == 'sqlite':
+                sqlitePath = os.path.join('var', '%s.db' % self[SYSTEM_NAME])
+                self[DB_NAME] = os.path.join(self[FILESYSTEM_PATH], sqlitePath)
+            else:
+                self[DB_NAME] = self[SYSTEM_NAME]
+        if not self[DB_USER]:
+            self[DB_USER] = self[SYSTEM_NAME]
         if not self[DB_SUPER_USER]:
             self[DB_SUPER_USER] = self[DB_USER]
         if not self[DB_SUPER_PASS]:
@@ -215,21 +252,29 @@ class SystemDictionary(dict):
                 self[PYTHONPATH] = self[VIRTUALENVBIN_PATH]+":"+self[PYTHONPATH]
             else:
                 self[PYTHONPATH] = self[VIRTUALENVBIN_PATH]
+        if not self[HTTP_AUTH_REALM]:
+            realm = self[SYSTEM_SERVICE_NAME]
+            realm = realm.decode('utf-8').replace('#', '\#')
+            self[HTTP_AUTH_REALM] = realm
             
     def setNewWordsFromOld(self):
         # Support usage of old dictionary words in existing config files.
-        if OLD_DB_PASS in self:
+        self.setNewWordFromOld(DB_PASS, OLD_DB_PASS)
+        self.setNewWordFromOld(MEDIA_PATH, OLD_MEDIA_PATH)
+   
+    def setNewWordFromOld(self, new, old):
+        if old in self:
             # Todo: Warn of deprecation.
-            if not self[DB_PASS]:
-                self[DB_PASS] = self.pop(OLD_DB_PASS)
-        if OLD_MEDIA_PATH in self:
-            # Todo: Warn of deprecation.
-            if not self[MEDIA_PATH]:
-                self[MEDIA_PATH] = self.pop(OLD_MEDIA_PATH)
+            if not self[new]:
+                self[new] = self.pop(old)
+   
     
     def getSystemVersion(self):
         return dm.__version__
 
+    def getSystemUserName(self):
+        return self.environment.getSystemUserName()
+
     def getSystemTitle(self):
         systemName = self[SYSTEM_NAME]
         if systemName == 'domainmodel':
@@ -270,7 +315,11 @@ class SystemDictionary(dict):
 
     def validateDictionaryWords(self):
         self.validateUriPrefix()
-        # todo: More dictionary word validation.
+        if self[APACHE_PYTHON_MODULE] not in ['mod_wsgi', 'mod_python']:
+            msg = "Neither 'mod_python' nor 'mod_wsgi' are set in configuration."
+            raise InvalidSystemDictionary, msg
+        # Todo: More dictionary word validation.
+        # Todo: Schema-based or model-based dictionary word validation.
 
     def validateUriPrefix(self):
         uriPrefix = self[URI_PREFIX]
