@@ -22,6 +22,8 @@ class DomainBase(object):
     registry         = RequiredFeature('DomainRegistry')
     pluginController = RequiredFeature('PluginController')
 
+    isObjectIdSignificant = True  # For object data migration.
+
     def resolvePathPart(self, pathPart):
         return getattr(self, pathPart)
 
@@ -459,14 +461,14 @@ class DomainObjectRegister(AbstractRegister):
         attrName = self.startsWithAttributeName or self.getKeyName()
         if attrName == 'id':
             msg = "Can't match start of 'id' attribute. Try setting the " 
-            msg += "'startsWithAttributeName' on class %s." % (
-                self.getDomainClassMeta().name
-            )
+            msg += "'searchAttributeNames' or 'startsWithAttributeName' "
+            msg += "on class %s." % self.getDomainClassMeta().name
             raise Exception(msg)
         return attrName
 
     def getSearchAttributeNames(self):
         "Returns name of attributes used for searching domain objects'."
+        # Todo: Support isSearchable attribute on meta attribute class, and gather them together into searchAttributeNames on class registration?
         return self.searchAttributeNames or [self.getStartsWithAttributeName()]
 
     def getObjectList(self):
