@@ -5,6 +5,8 @@ Meta classes describe the DomainObject classes.
 # Todo: Rename convertor to converter (spelling).
 
 from dm.ioc import *
+from dm.messagedigest import hmac
+from dm.messagedigest import sha256
 from dm.messagedigest import md5
 from dm.datetimeconvertor import DateTimeConvertor
 from dm.datetimeconvertor import RDateTimeConvertor
@@ -14,6 +16,7 @@ from dm.datetimeconvertor import RDateConvertor
 from dm.datetimeconvertor import DateOfBirthConvertor
 from dm.dictionarywords import IMAGES_DIR_PATH
 from dm.dictionarywords import DB_MIGRATION_IN_PROGRESS
+from dm.dictionarywords import PASSWORD_DIGEST_SECRET
 import os
 import inspect
 from dm.exceptions import *
@@ -299,6 +302,7 @@ class ValueObjectAttr(MetaDomainAttr):
     "Models a domain object value attribute."
 
     isValueRef = True
+    isString = False
     isBoolean = False
     isNumber = False
     isDateTime = False
@@ -331,6 +335,8 @@ class ValueObjectAttr(MetaDomainAttr):
 class String(ValueObjectAttr):
     "Models a domain object string attribute."
 
+    isString = True
+
     def __init__(self, default='', **kwds):
         super(String, self).__init__(default=default, **kwds)
 
@@ -341,6 +347,7 @@ class Text(String):
     def __init__(self, default='', **kwds):
         super(Text, self).__init__(default=default, **kwds)
 
+
 from markdown import Markdown
 class MarkdownText(Text):
     "Models a 'markdown' textual attribute."
@@ -394,7 +401,14 @@ class Password(String):
 
     def makeDigest(self, clearText):
         clearText = unicode(clearText).encode('utf-8')
-        return md5(clearText).hexdigest()
+        # First follow original method (migrated passwords rehashed in v0.19).
+        md5hexdigest = md5(clearText).hexdigest() 
+        # Now protect passwords better than just using MD5 once. The aim
+        # is to put the password digests beyond the scope of rainbow tables
+        # so that if the database is stolen, it will be more difficult to
+        # obtain passwords (users sometimes register email account passwords).
+        key = self.dictionary[PASSWORD_DIGEST_SECRET]
+        return hmac(key=key, msg=md5hexdigest, digestmod=sha256).hexdigest()
 
     def setAttributeValue(self, domainObject, attrValue):
         if attrValue:
@@ -498,6 +512,7 @@ class Boolean(ValueObjectAttr):
         else:
             return 'Off'
 
+
 class NumberObjectAttr(ValueObjectAttr):
 
     isNumber = True
@@ -1025,6 +1040,7 @@ class AssociateList(DomainObjectAssociation):
         associationObject = register[keyValue]
         return associationObject
 
+
 class HasA(Associate):
     "Models aquaintance with a domain object."
     pass
@@ -1039,4 +1055,3 @@ class AggregatesMany(Aggregation, HasMany):
     "Models aggregation of several domain objects."
     pass
 
-
