@@ -1,7 +1,7 @@
 from dm.dom.stateful import *
 from dm.ioc import *
-import md5
-import sha
+from dm.messagedigest import md5
+#import dm.messagedigest import sha
 
 class Person(StandardObject):
     "Registered person."
