@@ -27,14 +27,6 @@ class Plugin(StandardObject):
             self.__system = self.systemFactory.getPlugin(self)
         return self.__system
 
-    def getMaxServicesPerProject(self):
-        "Returns the maximum service instances for any project."
-        pluginSystem = self.getSystem()
-        if pluginSystem:
-            return pluginSystem.getMaxServicesPerProject()
-        else:
-            return None
-
     def extendsDomainModel(self):
         "Whether or not the plugin system has it's own domain objects."
         return self.getSystem().extendsDomainModel
