@@ -1,14 +1,12 @@
 import random
 import sys
-import mx.DateTime
-import datetime
-import time
 from dm.ioc import *
 from dm.dom.stateful import *
 from dm.messagedigest import md5
 from dm.dictionarywords import WEBKIT_NAME
 from dm.dictionarywords import DJANGO_SECRET_KEY
 from dm.exceptions import WebkitError
+import dm.times
 import string
 import random
 
@@ -19,7 +17,7 @@ class Session(SimpleDatedObject):
     isUnique        = False
     key             = String(default='', isRequired=False)
     person          = HasA('Person', default=None)
-    lastVisited     = DateTime(default=mx.DateTime.now, isRequired=False)
+    lastVisited     = DateTime(default=dm.times.getLocalNow, isRequired=False)
 
     def initialise(self, register):
         super(Session, self).initialise(register)
@@ -41,9 +39,10 @@ class Session(SimpleDatedObject):
         return sessionKey
 
     def updateLastVisited(self):
-        nowTime = mx.DateTime.now()
+        nowTime = dm.times.getLocalNow()
         try:
-            if (int(nowTime) > int(self.lastVisited) + 10):
+            deltaSinceLastVisited = nowTime - self.lastVisited
+            if deltaSinceLastVisited.days or deltaSinceLastVisited.seconds > 10:
                 self.lastVisited = nowTime
                 self.save()
         except Exception, inst:
