@@ -4,7 +4,7 @@ from dm.exceptions import *
 from dm.dom.stateful import SimpleObject, SimpleNamedObject, NamedStatefulObject, StatefulObject, String, DateTime, HasA, HasMany, AggregatesMany
 from dm.dom.base import DomainObjectRegister
 from dm.ioc import RequiredFeature
-import mx.DateTime
+import datetime
 import dm.times
 from time import sleep
 from dm.dom.temporal import TemporalProperty, BitemporalProperty, BitemporalActual
@@ -256,14 +256,14 @@ class TestTemporalProperty(TestCase):
         self.failUnlessEqual(self.property.getSortOnValue(), (self.property.dateCreated, self.property.id))
 
     def test_getFindTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.recorded = time1
         self.failUnlessEqual(self.collection.getFindTime(), time1)
         sleep(0.1)
         self.failUnlessEqual(self.collection.getFindTime(), time1)
 
     def test_getCreateTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.recorded = time1
         sleep(0.1)
         self.failUnlessEqual(self.collection.getCreateTime(), time1)
@@ -299,10 +299,10 @@ class TestBitemporalActual(TestCase):
         self.failUnlessEqual(BitemporalActual.sortAscending, False)
 
     def test_instance(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
-        time2 = mx.DateTime.DateTime(2003, 7, 1)
-        time3 = mx.DateTime.DateTime(2003, 8, 1)
-        time4 = mx.DateTime.DateTime(2003, 8, 1)
+        time1 = datetime.datetime(2003, 6, 1)
+        time2 = datetime.datetime(2003, 7, 1)
+        time3 = datetime.datetime(2003, 8, 1)
+        time4 = datetime.datetime(2003, 8, 1)
         property1 = self.collection.create(dateCreated=time1, recordedValue="1")
         property2 = self.collection.create(dateCreated=time3, recordedValue="2")
         property3 = self.collection.create(dateCreated=time2, recordedValue="3")
@@ -328,7 +328,7 @@ class TestBitemporalActual(TestCase):
             property1.delete()
 
     def test_getFindTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.actual = time1
         self.failUnlessEqual(self.collection.getFindTime(), time1)
         self.timepoint.reset()
@@ -337,7 +337,7 @@ class TestBitemporalActual(TestCase):
         self.failIfEqual(self.collection.getFindTime(), time1)
 
     def test_getCreateTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.actual = time1
         self.failUnlessEqual(self.collection.getCreateTime(), time1)
         self.timepoint.reset()
@@ -370,10 +370,10 @@ class TestBitemporalProperty(TestCase):
         self.failUnlessEqual(TemporalProperty.sortAscending, False)
 
     def test_instance(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
-        time2 = mx.DateTime.DateTime(2003, 7, 1)
-        time3 = mx.DateTime.DateTime(2003, 8, 1)
-        time4 = mx.DateTime.DateTime(2003, 8, 1)
+        time1 = datetime.datetime(2003, 6, 1)
+        time2 = datetime.datetime(2003, 7, 1)
+        time3 = datetime.datetime(2003, 8, 1)
+        time4 = datetime.datetime(2003, 8, 1)
 #        property1 = self.collection.create(recordedValue="1")
 #        property2 = self.collection.create(recordedValue="2")
 #        property3 = self.collection.create(recordedValue="3")
@@ -395,10 +395,10 @@ class TestBitemporalProperty(TestCase):
 #            property1.delete()
 
     def test_instance_actualtime_changes(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
-        time2 = mx.DateTime.DateTime(2003, 7, 1)
-        time3 = mx.DateTime.DateTime(2003, 8, 1)
-        time4 = mx.DateTime.DateTime(2003, 8, 1)
+        time1 = datetime.datetime(2003, 6, 1)
+        time2 = datetime.datetime(2003, 7, 1)
+        time3 = datetime.datetime(2003, 8, 1)
+        time4 = datetime.datetime(2003, 8, 1)
 #        property1 = self.collection.create()
 #        property1.recordedValue = "1"
 #        property1.save()
@@ -427,7 +427,7 @@ class TestBitemporalProperty(TestCase):
 #            property1.delete()
 
     def test_getFindTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.recorded = time1
         self.failUnlessEqual(self.collection.getFindTime(), time1)
         sleep(0.1)
@@ -436,7 +436,7 @@ class TestBitemporalProperty(TestCase):
         self.failUnless(self.collection.getFindTime() > time1)
 
     def test_getCreateTime(self):
-        time1 = mx.DateTime.DateTime(2003, 6, 1)
+        time1 = datetime.datetime(2003, 6, 1)
         self.timepoint.recorded = time1
         sleep(0.1)
         self.failUnlessEqual(self.collection.getCreateTime(), time1)
@@ -522,14 +522,14 @@ class TestTemporal(TestCase):  # Example
         
         color1 = "First Color"
         color2 = "Second Color"
-        changeTime1 = mx.DateTime.DateTime(2000, 1, 1, 0, 0 ,0)
-        updateTime1 = mx.DateTime.DateTime(2003, 6, 1, 0, 0 ,0)
-        beforeChange2 = mx.DateTime.DateTime(2003, 12, 1, 0, 0, 0)
-        changeTime2 = mx.DateTime.DateTime(2004, 1, 1, 0, 0 ,0)
-        afterChange2 = mx.DateTime.DateTime(2004, 1, 2, 0, 0, 0)
-        beforeUpdate2 = mx.DateTime.DateTime(2004, 1, 9, 0, 0, 0)
-        updateTime2 = mx.DateTime.DateTime(2004, 1, 10, 0, 0 ,0)
-        afterUpdate2 = mx.DateTime.DateTime(2004, 1, 10, 0, 0, 0)
+        changeTime1 = datetime.datetime(2000, 1, 1, 0, 0 ,0)
+        updateTime1 = datetime.datetime(2003, 6, 1, 0, 0 ,0)
+        beforeChange2 = datetime.datetime(2003, 12, 1, 0, 0, 0)
+        changeTime2 = datetime.datetime(2004, 1, 1, 0, 0 ,0)
+        afterChange2 = datetime.datetime(2004, 1, 2, 0, 0, 0)
+        beforeUpdate2 = datetime.datetime(2004, 1, 9, 0, 0, 0)
+        updateTime2 = datetime.datetime(2004, 1, 10, 0, 0 ,0)
+        afterUpdate2 = datetime.datetime(2004, 1, 10, 0, 0, 0)
 
         temporal = self.temporals[self.fixtureName]
         #  Check that we currently have first value before time of 2nd change.
@@ -612,9 +612,9 @@ class TestTemporal(TestCase):  # Example
         state1 = self.registry.states['active']
         state2 = self.registry.states['pending']
         state3 = self.registry.states['deleted']
-        time1 = mx.DateTime.DateTime(2007, 6, 1, 0, 0 ,0)
-        time2 = mx.DateTime.DateTime(2007, 7, 1, 0, 0 ,0)
-        time3 = mx.DateTime.DateTime(2007, 8, 1, 0, 0 ,0)
+        time1 = datetime.datetime(2007, 6, 1, 0, 0 ,0)
+        time2 = datetime.datetime(2007, 7, 1, 0, 0 ,0)
+        time3 = datetime.datetime(2007, 8, 1, 0, 0 ,0)
         description1 = "Description One"
         description2 = "Description Two"
         description3 = "Description Three"
