@@ -31,10 +31,11 @@ class TestLogger(TestCase):
     
     def testLogWarning(self):
         self.log.warning('Warning logging test. Please ignore this message.')
-    
-    def testLogError(self):
-        self.log.error('Error logging test. Please ignore this message.')
-    
-    def testLogCritical(self):
-        self.log.critical('Critical logging test. Please ignore this message.')
+
+# Todo: Fixup not printing log to STDOUT during the tests.
+#    def testLogError(self):
+#        self.log.error('Error logging test. Please ignore this message.')
+#    
+#    def testLogCritical(self):
+#        self.log.critical('Critical logging test. Please ignore this message.')
 
