@@ -19,13 +19,13 @@ class PluginBase(object):
         self.domainObject = domainObject   # The application's model of this plugin.
         self.register = self.getRegister() # A register of extention model objects.
 
-    def checkDir(self):
-        pluginPath = self.getDirPath()
-        if not os.path.exists(pluginPath):
-            os.makedirs(pluginPath)
-
-    def getDirPath(self):
-        return self.paths.getPluginPath(self.domainObject)
+#    def checkDir(self):
+#        pluginPath = self.getDirPath()
+#        if not os.path.exists(pluginPath):
+#            os.makedirs(pluginPath)
+#
+#    def getDirPath(self):
+#        return self.paths.getPluginPath(self.domainObject)
     
     def getRegister(self):
         if self.extendsDomainModel:
