@@ -10,6 +10,8 @@ from dm.strategy import MakeCookieString
 from dm.strategy import ValidateCookieString
 from dm.util.datastructure import MultiValueDict
 from dm.webkit import HttpResponse
+from dm.webkit import HttpResponseBadRequest
+from dm.webkit import HttpResponseNotFound
 from dm.webkit import HttpResponseRedirect
 from dm.webkit import Context
 from dm.webkit import RequestContext
@@ -387,6 +389,27 @@ class ControlledAccessView(object):
         )
         return HttpResponse(msg)
 
+    def getNotFoundResponse(self):
+        return HttpResponseNotFound(self.getNotFoundResponseBody())
+
+    def getNotFoundResponseBody(self):
+        body = """<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
+<html><head>
+<title>404 Not Found</title>
+</head><body>
+<h1>Not Found</h1>
+<p>The requested URL %(path)s was not found on this service.</p>
+<hr>
+<address>%(system)s-%(version)s service at %(domain)s </address>
+</body></html>"""
+        body %= {
+            'path': self.path,
+            'system': self.dictionary[SYSTEM_NAME],
+            'version': self.dictionary[SYSTEM_VERSION],
+            'domain': self.dictionary[DOMAIN_NAME]
+        }
+        return body
+
 
 class SessionView(ControlledAccessView):
 
@@ -485,7 +508,12 @@ class SessionView(ControlledAccessView):
             webkitName = self.dictionary[WEBKIT_NAME]
             if webkitName == 'django':
                 self.setContext()
-        self.createResponse()
+        if not self.redirect:
+            self.createContent()
+        if self.redirect:
+            self.createRedirectResponse()
+        else:
+            self.createResponse()
         self.setSessionCookie()
         if moddebug:
             msg = "%s: Returning response: %s" % (self.__class__.__name__, repr(self.response))
@@ -564,22 +592,12 @@ class SessionView(ControlledAccessView):
             else:
                 item['isCurrentItem'] = False
 
+    def createRedirectResponse(self):
+        self.response = HttpResponseRedirect(self.redirect)
+
     def createResponse(self):
-        webkitName = self.dictionary[WEBKIT_NAME]
-        if self.redirect:
-            if webkitName == 'django':
-                self.response = HttpResponseRedirect(self.redirect)
-        else:
-            self.createContent()
-            if self.redirect:
-                if webkitName == 'django':
-                    self.response = HttpResponseRedirect(self.redirect)
-            else:
-                if webkitName == 'django':
-                    self.response = HttpResponse(self.content)
-                    self.response.status_code = self.responseStatusCode
-                elif webkitName == 'pylons':
-                    self.response = self.content
+        self.response = HttpResponse(self.content)
+        self.response.status_code = self.responseStatusCode
            
     def createContent(self):
         webkitName = self.dictionary[WEBKIT_NAME]
@@ -791,6 +809,7 @@ class SessionView(ControlledAccessView):
         msg +=" (%ss)" % (dm.times.getLocalNow() - self.handlingStarted).seconds
         return msg
 
+
 class AbstractClassView(SessionView):
 
     registerSizeThreshold = 50
@@ -819,11 +838,12 @@ class AbstractClassView(SessionView):
         if self.domainObject == None:
             if self.domainObjectKey:
                 objectRegister = self.getDomainObjectRegister()
-                if objectRegister.isStateful:
-                    self.domainObject = objectRegister.getAll()[self.domainObjectKey]
-                else:
-                    self.domainObject = objectRegister[self.domainObjectKey]
-            
+                # Todo: Watch out for any problems that follow from showing only active items.
+                #if objectRegister.isStateful:
+                #    self.domainObject = objectRegister.getAll()[self.domainObjectKey]
+                #else:
+                #    self.domainObject = objectRegister[self.domainObjectKey]
+                self.domainObject = objectRegister[self.domainObjectKey]
         return self.domainObject
         
     def getManipulatedDomainObject(self):
@@ -838,6 +858,18 @@ class AbstractInstanceView(AbstractClassView):
             self.domainObjectKey = domainObjectKey
         self.manipulator = None
 
+    def getResponse(self):
+        if self.isResourceNotFound():
+            return self.getNotFoundResponse()
+        else:
+            return super(AbstractInstanceView, self).getResponse()
+
+    def isResourceNotFound(self):
+        try:
+            self.getManipulatedDomainObject()
+        except KforgeRegistryKeyError:
+            return True
+
     def setContext(self):
         super(AbstractInstanceView, self).setContext()
         domainObject = self.getDomainObject()
@@ -966,6 +998,12 @@ class AbstractFormView(AbstractInstanceView):
         )
         raise Exception(msg)
 
+    def createResponse(self):
+        if self.formErrors:
+            self.response = HttpResponseBadRequest(self.content)
+        else:
+            super(AbstractFormView, self).createResponse()
+
 
 class AbstractInputFormView(AbstractFormView):
 
