@@ -726,8 +726,6 @@ class FormFieldWrapper(object):
                 self.field_required = field.required
             if hasattr(field, 'field_title'):
                 self.field_title = field.field_title
-            if hasattr(field, 'label'):
-                self.field_title = field.label
             if hasattr(field, 'field_comment'):
                 self.field_comment = field.field_comment
             elif hasattr(field, 'help_text'):
